#!/usr/bin/perl
###############
#List of CNS input files in $PMB_HOME/CNS/
@filenames=qw(bindividual minimize anneal bdomain rigid water_pick qindividual 
FoFc_calc ncs-shake ncs_average_map omitmap model_map xtal_pdbsubmission 
deposit_mmcif pmb_check qgroup 
pmb_resolve pmb_omitmap pmb_ncs_avg 
FoFc_coot 2FoFc_coot);
# List of files to be COPIED 
@otherfiles=qw(/CNS/gener*.inp /CNS/*.def /CNS/pmb_param.inp 
/CNS/END.PDB pmb_start pmb_cns2phs pmb_refine pmb_coot 
/CNS/ligand.param /CNS/ligand.top 
hbonds-vu.scm pmb_my_hbonds.inp pmb_lpurge pmb_purge);
###############
printf "Syntax:\n";
printf "pmb_CNS  A B C alpha beta gamma \"Space_Group\" SG_No. Resolution\n"; 
printf "Example:\n";
printf "pmb_CNS 47.59 47.59 62.73 90 90 90 \"P4(1)\" 76 1.9\n";
printf "Notes:\n";
printf "This script creates bindividual, minimize, anneal, rigid, water_pick, \n";
printf "and FoFc_calc ...CNS refinement input files and scripts in your directory.\n";
###############
if($#ARGV<8) {printf"Insufficient arguments\n"; exit;}
#
for($i=0;$i<=$#ARGV;$i++){
$aa=$ARGV[0];$bb=$ARGV[1];$cc=$ARGV[2];
$alpha=$ARGV[3];$beta=$ARGV[4];$gamma=$ARGV[5];
$SG=$ARGV[6];
$SGN=$ARGV[7];
$RES=$ARGV[8];
}
#Get $PMB_HOME environmental variable
$pmb_dir_path= $ENV{PMB_HOME}."\/";
#
foreach $filename (@filenames) {
($fullpath=$pmb_dir_path."CNS/".$filename)=~s/\/\//\//g;
#printf"Open: %s %6.1f %6.1f %6.1f %6.1f %6.1f %6.1f %s %d %6.2f\n",$filename,$aa,$bb,$cc,$alpha,$beta,$gamma,$SG,$SGN,$RES;
#print "Opened: ".$fullpath."\n";
open IN ,"<  ".$fullpath or die "Failed to open $fullpath \nCheck $PMB_HOME is set       Program failed";
###open IN ,"< /usr1/local/PMB/CNS/$filename";
open OUT ,"> $filename.inp";

while(<IN>){
	$_=~s/CELL_AA/$aa/;
	$_=~s/CELL_BB/$bb/;
	$_=~s/CELL_CC/$cc/;
	$_=~s/CELL_ALPHA/$alpha/;
	$_=~s/CELL_BETA/$beta/ ;
	$_=~s/CELL_GAMMA/$gamma/;
	$_=~s/CELL_SG/$SG/;
	$_=~s/CELL_NSG/$SGN/;
	$_=~s/RES_HIGH/$RES/;
	print OUT $_ ;
	}
close IN;
printf "Created: %s.inp\n",$filename;
}
# Make CCP4 scripts executable
system("/bin/mv pmb_resolve.inp    pmb_resolve ;chmod +x *pmb_resolve");
system("/bin/mv pmb_omitmap.inp    pmb_omitmap ;chmod +x *pmb_omitmap");
system("/bin/mv pmb_ncs_avg.inp    pmb_ncs_avg ;chmod +x *pmb_ncs_avg");
system("/bin/mv pmb_check.inp      pmb_check   ;chmod +x *pmb_check");
#
#Copy "Otherfiles" into directory
foreach $filename (@otherfiles) {
	($fullpath=$pmb_dir_path.$filename)=~s/\/\//\//g;
	system("/bin/cp $fullpath .");
	}
#
# Allow Fobs.cv to be "local scaled"
system("chmod u+rw Fobs.cv");
#
# Create "logs" subdirectory
system("mkdir logs");
#
# Make the XtalView CRYSTAL PROJECT files
Get_PROJ();
Xtal_Info();
#
#
#
print "------------------------ \n";
print "If you have already run: \n";
print "\$PMB_BIN/pmb_sca2cns.exe ScalePack.sca \n";
print "to generate your Fobs.o.cv and Fobs.cv files, then run: \n";
print "======================= \n";
print " pmb_start {Model.pdb}  \n";
print "======================= \n";
print "to set up your CNS PDB model input files. \n";
print "To refine your model run pmb_refine.  There are many flags which \n";
print "pmb_refine recognizes, use the -h flag to get the current list.\n";
print "==================================== \n";
print " pmb_refine.pl -g |tee {LogFile.log} \n";
print "==================================== \n";
print "The ligand.top and ligand.param files will need to be edited for any ligands.\n";
print "If you have not recompiled CNS with pmb_bncs.f then you MUST edit  \n";
print "pmb_param.inp OR bindividual.inp:  Enter a negative bvsigma_scale value (-4).\n";
#
exit;
#
################################################################################
# Use CWD as PROJect Name #
###########################
sub Get_PROJ {
@proj=split("/", $ENV{PWD});foreach $dir (@proj){$PRJ=sprintf"%s",$dir}
$PRJ=~ s/[ ,\@,\\,\/,\~,\n]//g;
# DEBUG# printf "REFINEMENT ID: %s   \tPROJECT: %s \n",$ID,$PRJ;
}
######################################
# Write a Xtal_info/ crystal file    #
######################################
sub Xtal_Info() {
#Get $HOME environmental variable
$user_home= $ENV{HOME}."\/";
($xtal_file= $user_home."/xtal_info/".$PRJ)=~s/\/\//\//g;
($xtal_crystals= $user_home."/xtal_info/crystals")=~s/\/\//\//g;
($xtal_projects= $user_home."/xtal_info/projects")=~s/\/\//\//g;
#Get $PWD environmental variable
$project_dir= $ENV{PWD};
#
use Fcntl;
sysopen(XVOUT, $xtal_file, O_WRONLY|O_EXCL|O_CREAT) or { my $errorflag=1 };
if ($errorflag==1) {
	printf "ARGGH! cannot open: ".$xtal_file." ... Is XtalView installed?\n";
	return;}
else {
	printf XVOUT "name ".$PRJ."\n";
	printf XVOUT "cell %6.2f %6.2f %6.2f  %6.2f %6.2f %6.2f \n",$aa,$bb,$cc,$alpha,$beta,$gamma;
	printf XVOUT "spgp %s %d 1 1 unknown\n",$SG,$SGN;
	printf XVOUT "symm x,y,z.\n";
	printf XVOUT "The Spacegroup number is %d\n",$SGN;
	printf XVOUT "\n";
	open(XVCR, ">> $xtal_crystals") or printf "Failed to open: $xtal_crystals" ;
	  printf XVCR "%s\n",$PRJ;
	close XVCR;
	open(XVPR, ">> $xtal_projects") or printf "Failed to open: $xtal_projects" ;
	  printf XVPR "%s (%s)\n",$PRJ,$SG;
	  printf XVPR "%s %s\n#\n",$project_dir,$PRJ;
	close XVPR;
	printf "Opened XtalView project: ".$xtal_file."\n";
	} 
close XVOUT;
#
}
####################################################
####################################################
####################################################
