/*                  P M B                                      */
/*            Protein Model Builder                            */
/*            pmb_sca2cv.c                                     */
/*                  (c)                                        */
/*            Mark A. White                                    */
/*            17 April, 1998  -  Oct 12, 2011                  */
/*      reads RC datafile     ASC file                         */
/*      reads Scalpack.out    ASC file                         */
/*      produces datafile.cv   Xplor.cv                        */
/*                                                             */
/* cc -o pmb_sca2cns_v19.x86_64 pmb_sca2cns_20111012.c -lm     */
/* cc -o pmb_sca2cns_v19.fc4 pmb_sca2cns_20111012.c -lm        */
/*								*/
/*awk ' { printf "%4d%4d%4d %10.3f %10.3f \n", $2,$3,$4, $6,$6 } ' *.cv  */
/*								*/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <math.h>
#include <ctype.h>
#include <time.h>
#define LAMBDA		 1.5418
#define RTD		    57.29578
#define EXTENSION	"cv"
#define NREFL		40000	/*  max NREFLections */
#define STSCALE		5432	/*  STSCALE > 100/stol(min)>1000 */
#define TPERCNT		20	/*  100/TPERCNT:100/(10)=10%, 100/[20]=5% */
#define column(n)   (buffer+(n)-1)
#define Bayes		1	/* Bayes F sigmaF estimations */
 
int main(int argc, char *argv[])
{
double DD;
char outfile[131];
/* */
printf("\n\t<*                  P M B                       *> \n");
printf(  "\t<*            Protein Model Builder             *> \n");
printf(  "\t<*              pmb_sca2cv.c                    *> \n");
printf(  "\t<*             (c) 1998-2007                    *> \n");
printf(  "\t<*             Mark A. White                    *> \n");
printf(  "\t<*             UTMB at Galveston                *> \n");
printf(  "\t<*        Original: 20 April, 1998              *> \n");
printf(  "\t<*        Last Update:  071211                  *> \n");
printf(  "\t<*        reads  Scalepack.out    ASCII file(s) *> \n");
printf(  "\t<*        writes Scalepack.out.cv    file(s)    *> \n");
printf(  "\t<*                                              *> \n");
printf(  "\t<*        Pick=%d%%,   STOL-Factor=%d           *> \n",100/TPERCNT, STSCALE );
printf("\n");
/* */
/* Check if there are files given, exit if none */
if(argc<=1) 
        {
        fprintf(stderr,"\n%s \n","ERROR: make_cv.exe - Insufficient arguments");
        fprintf(stderr,"\tUsage: %s \n\n\a","make_cv.exe  {filename(s)} ");
        exit(0);
        }
/* Convert all filename(s) given, output with filename.cv extension */
/* DD=atof(argv[argc-1]); */
while(--argc>0)
    {
    sprintf(outfile,"%s.%s", *++argv, EXTENSION);
    printf("%3d:make_cv(%s, %s)\n", argc,*argv, outfile);
    if(make_cv(*argv, outfile)!=NULL) 
	fprintf(stderr,"%s \n","make_cv: read/write error");


    }/* end while argc */
printf("\nDONE: \n\a\a");
exit(0);
}/* end main */
/* ================================================================== */
/* === make_cv ===  === make_cv ===  === make_cv ===  === make_cv === */
/* This subroutine will read a ScalePack format input file and create a */
/* XPLOR/CNS format *.cv file with a TEST flag which is based on thin   */
/* equally spaced in STOL shells.  The purpose of this is to reduce     */
/* the effect of NCS on the R-free.				        */
/* === make_cv ===  === make_cv ===  === make_cv ===  === make_cv === */
/* ================================================================== */
int make_cv(char rfilename[81],  char wfilename[81])
/* ================================================================== */
{
FILE *fpr,*fpw;
int h=0, k=0, l=0, i=0, j=0, n=0, loop, sgn;
int numberoflines,  test;
float  aa, bb, cc, alpha, beta, gamma;
float  astar, bstar, cstar, cosas,  cosbs,  cosgs;
float  INT, SI, SISQ, FSQR, INT2, SI2,  vol, stol;
float  FOBS, SF, ds, dvalue, max_res=999;
char spacegroup[20], buffer[200], buf[30], *stop;
time_t *tp1, *tp2;
/*+++++++++++++++++++++++++++++++++++++++++++++++++++OPEN FILES */
if((fpr=fopen(rfilename,"r"))==NULL) 
	{
	fprintf(stderr,"%s:%d:%s\n", "make_cv: Failed to open file",fpr,rfilename);
	return(fclose(fpr));
	}/*fopen*/
else printf("  Opened file: %s \n",rfilename);
if((fpw=fopen(wfilename,"w"))==NULL) 
	{
	fprintf(stderr,"%s:%d:%s\n", "make_cv: Failed to open file",fpw,wfilename);
	return(fclose(fpw));
	}/*fopen*/
else printf("Creating file: %s \n",wfilename);
/*+++++++++++++++++++++++++++++++++++++++++++read SP file h k l I sI ===*/
/*    1									*/
/* -987									*/
/*    47.724    47.724    63.782    90.000    90.000    90.000 p41 	*/            
/*   0   0  16 64719.4  1766.9						*/
fscanf(fpr, "%s\n", &buffer);
/* fprintf(fpw, "    %s\n",buffer); */
printf("\n Now Reading ScalePack.out File:\n\n%s\n",buffer);
fscanf(fpr, "%s\n", &buffer);
/* fprintf(fpw, " %s\n",buffer); */
printf("%s\n",buffer);
fscanf(fpr, "%f %f %f %f %f %f %s\n", &aa, &bb, &cc, &alpha, &beta, &gamma, &buffer);
/* fprintf(fpw, " %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %s\n", aa, bb, cc, alpha, beta, gamma, buffer); */
printf(" %9.3f %9.3f %9.3f %9.3f %9.3f %9.3f %s\n", aa, bb, cc, alpha, beta, gamma, buffer);
/*------------*/
/* SPACEGROUP */
buffer[0]=toupper(buffer[0]);

if(strcmp(buffer,"P1")==0)          {strcpy(spacegroup,"P1");sgn=1;}

else if(strcmp(buffer,"P2")==0)     {strcpy(spacegroup,"P2");sgn=3;}
else if(strcmp(buffer,"P21")==0)    {strcpy(spacegroup,"P2(1)");sgn=4;}
else if(strcmp(buffer,"C2")==0)     {strcpy(spacegroup,"C2");sgn=5;}

else if(strcmp(buffer,"P222")==0)   {strcpy(spacegroup,"P222");sgn=16;}
else if(strcmp(buffer,"P2221")==0)  {strcpy(spacegroup,"P222(1)");sgn=17;}
else if(strcmp(buffer,"P21212")==0) {strcpy(spacegroup,"P2(1)2(1)2");sgn=18;}
else if(strcmp(buffer,"P212121")==0){strcpy(spacegroup,"P2(1)2(1)2(1)");sgn=19;}

else if(strcmp(buffer,"C222")==0)   {strcpy(spacegroup,"C222");sgn=21;}
else if(strcmp(buffer,"C2221")==0)  {strcpy(spacegroup,"C222(1)");sgn=20;}

else if(strcmp(buffer,"F222")==0)   {strcpy(spacegroup,"F222");sgn=22;}

else if(strcmp(buffer,"I222")==0)   {strcpy(spacegroup,"I222");sgn=23;}
else if(strcmp(buffer,"I212121")==0){strcpy(spacegroup,"I2(1)2(1)2(1)");sgn=24;}

else if(strcmp(buffer,"P4")==0)     {strcpy(spacegroup,"P4");sgn=75;}
else if(strcmp(buffer,"P41")==0)    {strcpy(spacegroup,"P4(1)");sgn=76;}
else if(strcmp(buffer,"P42")==0)    {strcpy(spacegroup,"P4(2)");sgn=77;}
else if(strcmp(buffer,"P43")==0)    {strcpy(spacegroup,"P4(3)");sgn=78;}

else if(strcmp(buffer,"P422")==0)   {strcpy(spacegroup,"P422");sgn=89;}
else if(strcmp(buffer,"P4212")==0)  {strcpy(spacegroup,"P42(1)2");sgn=90;}
else if(strcmp(buffer,"P4122")==0)  {strcpy(spacegroup,"P4(1)22");sgn=91;}
else if(strcmp(buffer,"P41212")==0) {strcpy(spacegroup,"P4(1)2(1)2");sgn=92;}
else if(strcmp(buffer,"P4222")==0)  {strcpy(spacegroup,"P4(2)22");sgn=93;}
else if(strcmp(buffer,"P42212")==0) {strcpy(spacegroup,"P4(2)2(1)2");sgn=94;}
else if(strcmp(buffer,"P4322")==0)  {strcpy(spacegroup,"P4(3)22");sgn=95;}
else if(strcmp(buffer,"P43212")==0) {strcpy(spacegroup,"P4(3)2(1)2");sgn=96;}

else if(strcmp(buffer,"I4")==0)     {strcpy(spacegroup,"I4");sgn=79;}
else if(strcmp(buffer,"I41")==0)    {strcpy(spacegroup,"I4(1)");sgn=80;}
else if(strcmp(buffer,"I422")==0)   {strcpy(spacegroup,"I422");sgn=97;}
else if(strcmp(buffer,"I4122")==0)  {strcpy(spacegroup,"I4(1)22");sgn=98;}

else if(strcmp(buffer,"P3")==0)     {strcpy(spacegroup,"P3");sgn=143;}
else if(strcmp(buffer,"P31")==0)    {strcpy(spacegroup,"P3(1)");sgn=144;}
else if(strcmp(buffer,"P32")==0)    {strcpy(spacegroup,"P3(2)");sgn=145;}

else if(strcmp(buffer,"P312")==0)   {strcpy(spacegroup,"P312");sgn=149;}
else if(strcmp(buffer,"P3112")==0)  {strcpy(spacegroup,"P3(1)12");sgn=151;}
else if(strcmp(buffer,"P3212")==0)  {strcpy(spacegroup,"P3(2)12");sgn=153;}

else if(strcmp(buffer,"P321")==0)   {strcpy(spacegroup,"P321");sgn=150;}
else if(strcmp(buffer,"P3121")==0)  {strcpy(spacegroup,"P3(1)21");sgn=152;}
else if(strcmp(buffer,"P3221")==0)  {strcpy(spacegroup,"P3(2)21");sgn=154;}

else if(strcmp(buffer,"P6")==0)     {strcpy(spacegroup,"P6");sgn=168;}
else if(strcmp(buffer,"P61")==0)    {strcpy(spacegroup,"P6(1)");sgn=169;}
else if(strcmp(buffer,"P65")==0)    {strcpy(spacegroup,"P6(5)");sgn=170;}
else if(strcmp(buffer,"P62")==0)    {strcpy(spacegroup,"P6(2)");sgn=171;}
else if(strcmp(buffer,"P64")==0)    {strcpy(spacegroup,"P6(4)");sgn=172;}
else if(strcmp(buffer,"P63")==0)    {strcpy(spacegroup,"P6(3)");sgn=173;}

else if(strcmp(buffer,"P622")==0)   {strcpy(spacegroup,"P622");sgn=177;}
else if(strcmp(buffer,"P6122")==0)  {strcpy(spacegroup,"P6(1)22");sgn=178;}
else if(strcmp(buffer,"P6522")==0)  {strcpy(spacegroup,"P6(5)22");sgn=179;}
else if(strcmp(buffer,"P6222")==0)  {strcpy(spacegroup,"P6(2)22");sgn=180;}
else if(strcmp(buffer,"P6422")==0)  {strcpy(spacegroup,"P6(4)22");sgn=181;}
else if(strcmp(buffer,"P6322")==0)  {strcpy(spacegroup,"P6(3)22");sgn=182;}

else if(strcmp(buffer,"R3")==0)     {strcpy(spacegroup,"R3");sgn=146;}
else if(strcmp(buffer,"R32")==0)    {strcpy(spacegroup,"R32");sgn=155;}

else if(strcmp(buffer,"I23")==0)    {strcpy(spacegroup,"I23");sgn=197;}
else if(strcmp(buffer,"I213")==0)   {strcpy(spacegroup,"I2(1)3");sgn=199;}
else if(strcmp(buffer,"I432")==0)   {strcpy(spacegroup,"I432");sgn=211;}
else if(strcmp(buffer,"I4132")==0)  {strcpy(spacegroup,"I4(1)32");sgn=214;}

else if(strcmp(buffer,"P23")==0)    {strcpy(spacegroup,"P23");sgn=195;}
else if(strcmp(buffer,"P213")==0)   {strcpy(spacegroup,"P2(1)3");sgn=198;}
else if(strcmp(buffer,"P432")==0)   {strcpy(spacegroup,"P432");sgn=207;}
else if(strcmp(buffer,"P4232")==0)  {strcpy(spacegroup,"P4(2)32");sgn=208;}
else if(strcmp(buffer,"P4332")==0)  {strcpy(spacegroup,"P4(3)32");sgn=212;}
else if(strcmp(buffer,"P4132")==0)  {strcpy(spacegroup,"P4(1)32");sgn=213;}

else {printf(" * Unknown Space Group *\n");strcpy(spacegroup,"P1");sgn=1;}

printf("Spacegroup %s\n",spacegroup);
/*#####################*/
/*--------------------------------------------------------------*/
/* These are needed to calculate STOL for determining TEST flag */    
alpha/=RTD;
beta/=RTD;
gamma/=RTD;
vol=aa*bb*cc*sqrt(1-cos(alpha)*cos(alpha)-cos(beta)*cos(beta)-cos(gamma)*cos(gamma)+2*cos(alpha)*cos(beta)*cos(gamma));
astar=bb*cc*sin(alpha)/vol;
bstar=aa*cc*sin(beta)/vol;
cstar=aa*bb*sin(gamma)/vol;
cosas=(cos(beta)*cos(gamma)-cos(alpha))/(sin(gamma)*sin(beta));
cosbs=(cos(alpha)*cos(gamma)-cos(beta))/(sin(alpha)*sin(gamma));
cosgs=(cos(alpha)*cos(beta)-cos(gamma))/(sin(alpha)*sin(beta));

fprintf(fpw, " NREFlection=     %d	\n", NREFL);
fprintf(fpw, " ANOMalous=FALSe { equiv. to HERMitian=TRUE}\n");
fprintf(fpw, " DECLare NAME=FOBS                   DOMAin=RECIprocal   TYPE=COMP END\n");
fprintf(fpw, " DECLare NAME=SIGMA                  DOMAin=RECIprocal   TYPE=REAL END\n");
fprintf(fpw, " DECLare NAME=TEST                   DOMAin=RECIprocal   TYPE=INTE END\n");

/*while( fscanf(fpr, "%d %d %d %f %f\n", &h, &k, &l, &INT, &SI)!=EOF ) */
while( fgets(buffer,200,fpr)!=NULL )
    {
/*#####1234567890123456789212345678
  #####   0   0  12  3993.0   245.6
  #####   0   0  4811540815  246363
  #####1234123412341234567812345678 */
/*#####   3   1  72    28.6     0.8    30.2     0.9
  #####1234123412341234567812345678 */
  
  	/*printf("%d\n",sscanf(buffer, "%d %d %d %f %f\n", &h, &k, &l, &INT, &SI));*/
/*	if(sscanf(buffer, "%d %d %d %f %f\n", &h, &k, &l, &INT, &SI)<5) {   */
/*	sscanf(buffer, "%d %d %d %f %f\n", &h, &k, &l, &INT, &SI);		*/
//	n=sscanf(buffer, "%d %d %d %f %f %f %f\n", &h, &k, &l, &INT, &SI, &INT2, &SI2);
//	n=sscanf(buffer, "%4d%4d%4d%8.1f%8.1f%8.1f%8.1f\n", &h, &k, &l, &INT, &SI, &INT2, &SI2);
//	n=sscanf(buffer, "%4d%4d%4d%8f%8f%8f%8f\n", &h, &k, &l, &INT, &SI, &INT2, &SI2);
//	n=sscanf(buffer, "%4.4d%4.4d%4.4d%8.f%8.f%8.f%8.f\n", &h, &k, &l, &INT, &SI, &INT2, &SI2);
        //FORMAT="I4,I4,I4,F8.1,F8.1"
        strsnip(&buffer, &buf, 0, 4);h=atoi(buf);
        strsnip(&buffer, &buf, 4, 4);k=atoi(buf);
        strsnip(&buffer, &buf, 8, 4);l=atoi(buf);
        strsnip(&buffer, &buf,12, 8);INT=atof(buf);
        strsnip(&buffer, &buf,20, 8);SI=atof(buf);
	if(strlen(buffer)>36){
          strsnip(&buffer, &buf,28,8);INT2=atof(buf);
          strsnip(&buffer, &buf,36,8);SI2=atof(buf);
	  INT+=INT2;INT/=2.0; SI+=SI2;SI/=2.0;
	  }
	if(l>999 || l< -999) {	
	  printf("ERROR:%s\n",buffer);
//	  sscanf(buffer, "%d %d %s %f\n", &h, &k, &buf, &SI);
//	  switch(strlen(buf)-8){
//	    case 1:{
//	          sscanf(buf,"%1d%f",&l, &INT);}break;
//	    case 2:{
//	          sscanf(buf,"%2d%f",&l, &INT);}break;
//	    case 3:{
//	          sscanf(buf,"%3d%f",&l, &INT);}break;
//          default:{printf("D:ERROR:%s :L=%d I=%f\n",buf,l, INT);}
//	    }
	  }
//	if(n>5){INT+=INT2;INT/=2.0; SI+=SI2;SI/=2.0;}  
	  
    			/*#### Calculate STOL for determining TEST flag ####*/    
    stol = h*h*astar*astar+k*k*bstar*bstar+l*l*cstar*cstar;
    stol += 2*h*k*astar*bstar*cosgs;
    stol += 2*h*l*astar*cstar*cosbs;
    stol += 2*k*l*bstar*cstar*cosas;
    ds=1.0/sqrt(stol);if(max_res>ds) max_res=ds;
			/*### Generate TEST flag based on similar STOL ###*/
    test=stol*STSCALE;
    test%=TPERCNT;
    if(test==0) test=1;
	else test=0;
			/*### Calculate FOBS and SigmaF ###*/    
    if ( Bayes ) { SISQ=SI*SI;
    	FOBS = 0.5 * sqrt(2.0*INT +sqrt(4.0*INT*INT+8.0*SISQ));
	FSQR=FOBS*FOBS;
	SF=sqrt(1.0/FSQR +2.0*(3.0*FSQR-INT)/SISQ);
	}
    else {
    	if( INT > 0 ) FSQR=INT;
		else FSQR=0;
    	FOBS=sqrt(FSQR);
    	SF=sqrt(FSQR + SI) - FOBS;
    	}
 			/* PRINT Reflections to XPLOR/CNS format file "argv.cv" */       
/*    fprintf(fpw, "%4d%4d%4d%8.1f%8.1f %6d\n", h, k, l, INT, SI, test); */
    fprintf(fpw, "INDEx%5d%5d%5d FOBS=%10.3f SIGMA=%10.3f TEST=%10d \n",h, k, l, FOBS, SF, test ); 
    if (l==0 && k==0) printf("%4d%4d%4d %12.1f %10.1f : test=%4d : stol=%8.5f \n", h, k, l, INT, SI, test, stol);
    } /* end while( fscanf(fpr, */
/**/
/*###*/
fclose(fpr)+fclose(fpw);
alpha*=RTD;beta*=RTD;gamma*=RTD;
/*###*/
printf("===============================================================================\n");
printf("Now creating your Fobs.o.cv and Fobs.cv files:\n");
sprintf(buffer,"chmod -w %s\n",wfilename);system(buffer);printf(buffer);
sprintf(buffer,"ln -s %s Fobs.o.cv\n",wfilename);system(buffer);printf(buffer);
{i=clock()/CLOCKS_PER_SEC;while((clock()/CLOCKS_PER_SEC-i) < 1.0){;}}
sprintf(buffer,"/bin/cp -f Fobs.o.cv Fobs.cv & \n");system(buffer);printf(buffer);
{i=clock()/CLOCKS_PER_SEC;while((clock()/CLOCKS_PER_SEC-i) < 1.0){;}}
sprintf(buffer,"chmod u+w Fobs.cv &\n");system(buffer);printf(buffer);
/*#################*/
/* Check CNS parameters */
/*#################*/
printf("\n\n\n===============================================================================\n");
printf("================= PROTEIN MODEL BUILDER CNS INPUT FILE CREATION ===============\n");
buf[0]='N';
while(buf[0]=='N'){
 printf("===============================================================================\n");
 printf("Please check the Cell, SPACEGROUP, and high resolution limit:\n\n");
 printf("\ta=%7.2f   b=%7.2f   c=%7.2f \n\n\tAlpha= %.2f   Beta= %.2f   Gamma= %.2f\n\n",aa,bb,cc,alpha,beta,gamma);
 printf("\tSpaceGroup= \"%s\"   SG_No= %d   Resolution= %.2f \n\n",spacegroup,sgn,max_res);
 printf("===============================================================================\n");
 printf("Are These values correct? (Y) (y/n) ");
 buf[0]='Y';
 //#buf[0]=toupper(getchar());
 //#printf("\n INPUT= %c %c \n",buf[0],buf[1]);
 if(buf[0]=='N'){
	printf("\nWhich parameter do you want to edit (a,b,c,alpha,beta,gamma,sg,sgn,res)?");
	//while(gets(buffer)!='\n'){};for(i=0;i<30;i++){getchar();}
	buffer[0]=toupper(getchar());buffer[0]='\0';
	for(i=0;i<strlen(buffer);i++){buffer[i]=toupper(buffer[i]);}
	if(strcmp(buffer,"A")>=0){printf("\n\nEnter new cell value (A=%.2f):",aa);astar=atof(buf);if(astar>5 && astar<999){aa=astar;}}
	if(strcmp(buffer,"B")>=0){printf("\n\nEnter new cell value (B=%.2f):",bb);astar=atof(buf);if(astar>5 && astar<999){bb=astar;}}
	if(strcmp(buffer,"C")>=0){printf("\n\nEnter new cell value (C=%.2f):",cc);astar=atof(buf);if(astar>5 && astar<999){cc=astar;}}
	if(strcmp(buffer,"AL")>=0){printf("\n\nEnter new cell value (Alpha=%.2f):",alpha);astar=atof(buf);if(astar>30 && astar<200){alpha=astar;}}
	if(strcmp(buffer,"BE")>=0){printf("\n\nEnter new cell value (Beta=%.2f):",beta);astar=atof(buf);if(astar>30 && astar<200){beta=astar;}}
	if(strcmp(buffer,"GA")>=0){printf("\n\nEnter new cell value (Gamma=%.2f):",gamma);astar=atof(buf);if(astar>30 && astar<200){gamma=astar;}}
	if(strcmp(buffer,"SG")>=1){printf("\n\nEnter new SpaceGroup (SG=%s):",spacegroup);for(i=0;i<strlen(spacegroup);i++){spacegroup[i]=toupper(spacegroup[i]);}}
	if(strcmp(buffer,"SGN")>=2){printf("\n\nEnter new SG number (SGN=%d):",sgn);astar=atoi(buf);if(astar>0 && astar<215){sgn=astar;}}
	}
 printf("\n\n");
 }
/*#################*/
/* Setup CNS files */
/*#################*/
printf("===============================================================================\n");
printf("================= PROTEIN MODEL BUILDER CNS INPUT FILE CREATION ===============\n");
printf("===============================================================================\n");
sprintf(buffer,"$PMB_HOME/pmb_CNS %.2f %.2f %.2f %.2f %.2f %.2f \"%s\" %d %.2f \n",aa,bb,cc,
	alpha,beta,gamma,spacegroup,sgn,max_res);
printf(buffer);system(buffer);
/*sprintf(buffer,"mv resolve_map.inp pmb_resolve ;chmod +x *pmb_resolve");system(buffer); */
/*sprintf(buffer,"mv pmb_check.inp   pmb_check   ;chmod +x *pmb_check");system(buffer); */
printf("===============================================================================\n");
printf("================= PROTEIN MODEL BUILDER CNS INPUT FILE CREATION ===============\n");
printf("===============================================================================\n");
printf("To create the CNS input files and scripts necessary for structure refinement \n");
printf("enter the following command.  Edit it if you want to change any prameters.\n");
printf("Check the SPACEGROUP and high resolution limit:\n\n");
printf("$PMB_HOME/pmb_CNS a b c alpha beta gamma \"Space_Group\" SG-No. high_resolution\n");
printf("===============================================================================\n");
printf(buffer);
printf("===============================================================================\n");
{i=clock()/CLOCKS_PER_SEC;while((clock()/CLOCKS_PER_SEC-i) < 5.0){;}}

return(0);
} /* end make_cv */
/*=================================================================*/


int strsnip(char *INSTR, char *OUTSTR, int startchr, int nchar)
{
int i;
if(nchar > 99){printf("String is too long\n");}
for(i=0; i<nchar; i++){
	OUTSTR[i]=INSTR[i+startchr];
	}
OUTSTR[i]='\0';
return(i);
}
